.. include:: ../../README.rst

This manual documents version |release|.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   parceqt.rst
   document.rst
   treebuilder.rst
   highlighter.rst
   formatter.rst
   util.rst
   treemodel.rst
   debug.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :doc:`changelog`
* :doc:`license`
